@@ -12,10 +12,11 @@ def tmp_tree_of_tests(testdir):
 
     """
 
-    utils_package = testdir.mkpydir('utils')
-    utils_package.join('__init__.py').write('')
+    utils_package = testdir.mkpydir("utils")
+    utils_package.join("__init__.py").write("")
 
-    utils_package.join('foo.py').write(py.code.Source('''
+    utils_package.join("foo.py").write(
+        py.code.Source('''
         def add(a, b):
             """
             >>> add(1, 1)
@@ -33,24 +34,31 @@ def tmp_tree_of_tests(testdir):
             -2
             """
             return a - b
-    '''))
+    ''')
+    )
 
     return testdir
 
 
-@pytest.mark.parametrize('bucket', [
-    'global',
-    'package',
-    'module',
-    'class',
-    'parent',
-    'grandparent',
-    'none',
-])
+@pytest.mark.parametrize(
+    "bucket",
+    [
+        "global",
+        "package",
+        "module",
+        "class",
+        "parent",
+        "grandparent",
+        "none",
+    ],
+)
 def test_doctests(tmp_tree_of_tests, get_test_calls, bucket):
     result1 = tmp_tree_of_tests.runpytest(
-        '--doctest-modules', '--random-order-bucket={0}'.format(bucket), '--verbose', '-s',
+        "--doctest-modules",
+        "--random-order-bucket={0}".format(bucket),
+        "--verbose",
+        "-s",
     )
     result1.assert_outcomes(passed=2, failed=0)
-    assert 'PytestWarning' not in result1.stdout.str()
-    assert 'PytestWarning' not in result1.stderr.str()
+    assert "PytestWarning" not in result1.stdout.str()
+    assert "PytestWarning" not in result1.stderr.str()
